@@ -16,11 +16,10 @@
 #
 """Module for azure data generators."""
 from nise.generators.azure.azure_generator import AZURE_COLUMNS  # noqa: F401
+from nise.generators.azure.azure_generator import AZURE_COLUMNS_V2  # noqa: F401
 from nise.generators.azure.azure_generator import AzureGenerator  # noqa: F401
-from nise.generators.azure.bandwidth_generator import BandwidthGenerator
-from nise.generators.azure.sql_database_generator import SQLGenerator
-from nise.generators.azure.storage_generator import StorageGenerator
-from nise.generators.azure.virtual_machine_generator import VMGenerator
-from nise.generators.azure.virtual_network_generator import VNGenerator
-
-AZURE_GENERATORS = [BandwidthGenerator, SQLGenerator, StorageGenerator, VMGenerator, VNGenerator]
+from nise.generators.azure.bandwidth_generator import BandwidthGenerator  # noqa: F401
+from nise.generators.azure.sql_database_generator import SQLGenerator  # noqa: F401
+from nise.generators.azure.storage_generator import StorageGenerator  # noqa: F401
+from nise.generators.azure.virtual_machine_generator import VMGenerator  # noqa: F401
+from nise.generators.azure.virtual_network_generator import VNGenerator  # noqa: F401
